@@ -149,11 +149,15 @@ FolderModel::FolderModel(QObject *parent) : QSortFilterProxyModel(parent),
     m_dirModel->setDirLister(dirLister);
     m_dirModel->setDropsAllowed(KDirModel::DropOnDirectory | KDirModel::DropOnLocalExecutable);
 
-    /*
-     * position dropped items at the desired target position
-     * delay this via queued connection, such that the row is available and can be mapped
-     * when we emit the move request
-     */
+    // If we have dropped items queued for moving, go unsorted now.
+    connect(this, &QAbstractItemModel::rowsAboutToBeInserted,
+            this, [this]() {
+            if (!m_dropTargetPositions.isEmpty()) {
+                setSortMode(-1);
+            }
+    });
+
+    // Position dropped items at the desired target position.
     connect(this, &QAbstractItemModel::rowsInserted,
             this, [this](const QModelIndex &parent, int first, int last) {
         for (int i = first; i <= last; ++i) {
@@ -163,11 +167,11 @@ FolderModel::FolderModel(QObject *parent) : QSortFilterProxyModel(parent),
             if (it != m_dropTargetPositions.end()) {
                 const auto pos = it.value();
                 m_dropTargetPositions.erase(it);
-                setSortMode(-1);
                 emit move(pos.x(), pos.y(), {url});
             }
         }
     });
+
     /*
      * Dropped files may not actually show up as new files, e.g. when we overwrite
      * an existing file. Or files that fail to be listed by the dirLister, or...
@@ -999,7 +1003,8 @@ void FolderModel::dragSelectedInternal(int x, int y)
 static bool isDropBetweenSharedViews(const QList<QUrl> &urls, const QUrl &folderUrl)
 {
     for (const auto &url : urls) {
-        if (folderUrl != url.adjusted(QUrl::RemoveFilename | QUrl::StripTrailingSlash)) {
+        if (folderUrl.adjusted(QUrl::StripTrailingSlash)
+               != url.adjusted(QUrl::RemoveFilename | QUrl::StripTrailingSlash)) {
             return false;
         }
     }
@@ -1268,13 +1273,7 @@ QVariant FolderModel::data(const QModelIndex& index, int role) const
     } else if (role == SelectedRole) {
         return m_selectionModel->isSelected(index);
     } else if (role == IsDirRole) {
-        const QUrl &url = data(index, UrlRole).value<QUrl>();
-
-        if (m_isDirCache.contains(url)) {
-            return m_isDirCache[url];
-        } else {
-            return isDir(mapToSource(index), m_dirModel);
-        }
+        return isDir(mapToSource(index), m_dirModel);
     } else if (role == IsLinkRole) {
         const KFileItem item = itemForIndex(index);
         return item.isLink();
@@ -1327,21 +1326,36 @@ bool FolderModel::isDir(const QModelIndex &index, const KDirModel *dirModel) con
         return true;
     }
 
+    auto it = m_isDirCache.constFind(item.url());
+    if (it != m_isDirCache.constEnd()) {
+        return *it;
+    }
+
     if (m_parseDesktopFiles && item.isDesktopFile()) {
         // Check if the desktop file is a link to a directory
         KDesktopFile file(item.targetUrl().path());
 
-        if (file.hasLinkType()) {
-            const QUrl url(file.readUrl());
-
-            if (!m_isDirCache.contains(item.url()) && KProtocolInfo::protocolClass(url.scheme()) == QStringLiteral(":local")) {
-                KIO::StatJob *job = KIO::stat(url, KIO::HideProgressInfo);
-                job->setProperty("org.kde.plasma.folder_url", item.url());
-                job->setSide(KIO::StatJob::SourceSide);
-                job->setDetails(0);
-                connect(job, &KJob::result, this, &FolderModel::statResult);
-            }
+        if (!file.hasLinkType()) {
+            return false;
         }
+
+        const QUrl url(file.readUrl());
+
+        // Check if we already have a running StatJob for this URL.
+        if (m_isDirJobs.contains(item.url())) {
+            return false;
+        }
+
+        if (KProtocolInfo::protocolClass(url.scheme()) != QStringLiteral(":local")) {
+            return false;
+        }
+
+        KIO::StatJob *job = KIO::stat(url, KIO::HideProgressInfo);
+        job->setProperty("org.kde.plasma.folder_url", item.url());
+        job->setSide(KIO::StatJob::SourceSide);
+        job->setDetails(0);
+        connect(job, &KJob::result, this, &FolderModel::statResult);
+        m_isDirJobs.insert(item.url(), job);
     }
 
     return false;
@@ -1354,11 +1368,13 @@ void FolderModel::statResult(KJob *job)
     const QUrl &url = statJob->property("org.kde.plasma.folder_url").value<QUrl>();
     const QModelIndex &idx = index(indexForUrl(url), 0);
 
-    if (idx.isValid()) {
+    if (idx.isValid() && statJob->error() == KJob::NoError) {
         m_isDirCache[url] = statJob->statResult().isDir();
 
         emit dataChanged(idx, idx, QVector<int>() << IsDirRole);
     }
+
+    m_isDirJobs.remove(url);
 }
 
 void FolderModel::evictFromIsDirCache(const KFileItemList& items)
